<?php

/**
 * 
 * Statistics Widget, displays visits of today, yesterday, last 7 days and total
 * @author George Mathew K < georgemathewk@yahoo.com >
 * @since 2.1.0 < Creation Date : 20-Jan-2012 > 
 *
 */


class TA_Visits extends WP_Widget {

	
	
	
	/**
	 * 
	 * Constructor function for setting up widget
	 * @author George Mathew K < georgemathewk@yahoo.com >
	 * @since 2.1.0
	 */
	public  function __construct(){
		$id_base = "ta_visits";
		$name = "Analyzer : Visits";
		$widget_options = array(
					'description'=>"A front end widget for visitor's statistics"		
				);
		$control_options = array();
		parent::__construct($id_base,$name,$widget_options,$control_options);
	}
	
	
	
	
	
	/**
	 * Widget's Options Form
	 * @author George Mathew K < georgemathewk@yahoo.com >
	 * @since 2.1.0
	 * @param array $instance Current settings
	 */
	public function form($instance){
		
		$defaults = array(
					'title'=>'Statistics : Visits',
					'today'=>true,
					'yesterday'=>true,
					'last7'=>false,
					'total'=>false,
					'powered'=>false
		
				);
				
		$instance = wp_parse_args((array)$instance,$defaults);
		
		?>
		
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>">Title</label>
			<input type="text" value="<?php if(isset($instance['title'])) echo $instance['title']; ?>" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" />
		</p>
		
		<p>
			<input type="checkbox" <?php checked( $instance['today'], true ); ?>  id="<?php echo $this->get_field_id('today'); ?>" name="<?php echo $this->get_field_name('today'); ?>" />
			<label for="<?php echo $this->get_field_id('today'); ?>" >Show Today's Count</label>
		</p>
		
		<p>
			<input type="checkbox" <?php checked( $instance['yesterday'], true ); ?>  id="<?php echo $this->get_field_id('yesterday'); ?>" name="<?php echo $this->get_field_name('yesterday'); ?>" />
			<label for="<?php echo $this->get_field_id('yesterday'); ?>">Show Yesterday's Count</label>
		</p>
		
		<p>
			<input type="checkbox" <?php checked( $instance['last7'], true ); ?>  id="<?php echo $this->get_field_id('last7'); ?>" name="<?php echo $this->get_field_name('last7'); ?>" />
			<label for="<?php echo $this->get_field_id('last7'); ?>">Show Last 7 Days' Count</label>
		</p>
		
		<p>
			<input type="checkbox" <?php checked( $instance['total'], true ); ?> id="<?php echo $this->get_field_id('total'); ?>" name="<?php echo $this->get_field_name('total'); ?>" />
			<label for="<?php echo $this->get_field_id('total'); ?>">Show All Time Count</label>
		</p>
		
		<p>
			<input type="checkbox" <?php checked( $instance['powered'], true ); ?> id="<?php echo $this->get_field_id('powered'); ?>" name="<?php echo $this->get_field_name('powered'); ?>" />
			<label for="<?php echo $this->get_field_id('powered'); ?>">Hide Powered by Text</label>
		</p>
		
		
		<br />
		
		
		
		<?php 
	}
	
	
	
	/**
	 * Updates the widget options
	 * @author George Mathew K < georgemathewk@yahoo.com >
	 * @since 2.1.0
	 * @param array $new_instance New settings for this instance as input by the user via form()
	 * @param array $old_instance Old settings for this instance
	 * @return array Settings to save or bool false to cancel saving
	 */
	public function update($new_instance, $old_instance){
		$instance = $old_instance;
		
		$instance['title'] = strip_tags( $new_instance['title'] );		
		$instance['today'] = isset($new_instance['today']);
		$instance['yesterday'] = isset($new_instance['yesterday']);
		$instance['last7'] = isset($new_instance['last7']);
		$instance['total'] = isset($new_instance['total']);
		$instance['powered'] = isset($new_instance['powered']);	

		update_option('ta_visit_powered',$instance['powered']);

		return $instance;		
	}
	
	
	/**
	 * Displays the widget content in front end - Client area
	 * @author George Mathew K < georgemathewk@yahoo.com >
	 * @since 2.1.0
	 * @param array $args Display arguments including before_title, after_title, before_widget, and after_widget.
	 * @param array $instance The settings for the particular instance of the widget
	 */
	public function widget($args, $instance) {
		extract($args);
		$title  = apply_filters('widget_title',$instance['title']);
		
		echo $before_widget;
		
		echo $before_title . $title . $after_title;
		
		if($instance['today'])
			echo "<p><span style='width:150px;float:left'>Today </span>: ".  $this->visits_today()  ."</p>";
		
		
			
		if($instance['yesterday'])
			echo "<p><span style='width:150px;float:left'>Yesterday </span>: ".  $this->visits_yesterday()  ."</p>";
		
		if($instance['last7'])
			echo "<p><span style='width:150px;float:left'>Last week </span>: ".  $this->visits_last7()  ."</p>";

		if($instance['total'])
			echo "<p><span style='width:150px;float:left'>All Time </span>: ".  $this->visits_total()  ."</p>";
			
		echo "<div align='center' id='wpta_powered'><a href='http://wptrafficanalyzer.in'>Powered by wpta</a></div>";

		echo $after_widget;
		
	}
	
	
	public function visits_today(){
		global $wpdb;
		$today = date("Y-m-d");
		$where_cond = " and date(vtime) = '" . $today . "'";
		$sql = 	" select count(*) as cnt from  ( select 1 " .
					" from ".$wpdb->prefix."tanalyzer_visits visits " .
					" where 1=1  " .
					" $where_cond " .				
					" " . ta_user_agent_where() . " " .
					" group by ip,user_agent, wpta_cookie " .
					" ) as t "	;		
		$cnt = $wpdb->get_col($sql,0);	// Returns an array
		return $cnt[0];
	}

	public function visits_yesterday(){
		global $wpdb;
		$yesterday = date("Y-m-d", strtotime("-1 day"));
		$where_cond = " and date(vtime) = '" . $yesterday . "'";
		$sql = 	" select count(*) as cnt from  ( select 1 " .
					" from ".$wpdb->prefix."tanalyzer_visits visits " .
					" where 1=1  " .
					" $where_cond " .				
					" " . ta_user_agent_where() . " " .
					" group by ip,user_agent, wpta_cookie " .
					" ) as t "	;		
		$cnt = $wpdb->get_col($sql,0);	// Returns an array
		return $cnt[0];
	}
	
	public function visits_last7(){
		global $wpdb;
		$start_date = date("Y-m-d", strtotime("-6 day"));
		$end_date = date("Y-m-d");		
		$where_cond = " and date(vtime) between  '" . $start_date . "'  and '". $end_date ."' ";
		$sql = 	" select count(*) as cnt from  ( select 1 " .
					" from ".$wpdb->prefix."tanalyzer_visits visits " .
					" where 1=1  " .
					" $where_cond " .				
					" " . ta_user_agent_where() . " " .
					" group by ip,user_agent, wpta_cookie " .
					" ) as t "	;		
		$cnt = $wpdb->get_col($sql,0);	// Returns an array
		return $cnt[0];
	}
	
	public function visits_total(){
		global $wpdb;
		$sql = 	" select count(*) as cnt from  ( select 1 " .
					" from ".$wpdb->prefix."tanalyzer_visits visits " .
					" where 1=1  " .				
					" " . ta_user_agent_where() . " " .
					" group by ip,user_agent, wpta_cookie " .
					" ) as t "	;		
		$cnt = $wpdb->get_col($sql,0);	// Returns an array
		return $cnt[0];
	}
	
	
	
	
	
}